==> OnlineStatus-REL1_35-1259221.tar.gz: OnlineStatus/OnlineStatus.i18n.magic.php <==
<?php
/**
 * Internationalization file for magic words.
 */

$magicWords = [];

/** English (English) */
$magicWords['en'] = [
	'onlinestatus_word' => [ '1', 'ONLINESTATUS' ],
	'onlinestatus_word_raw' => [ '1', 'RAWONLINESTATUS' ],
	'anyuseronlinestatus' => [ 0, 'anyuseronlinestatus' ],
];

/** Arabic (العربية) */
$magicWords['ar'] = [
	'onlinestatus_word' => [ 'حالة_الاتصال' ],
	'onlinestatus_word_raw' => [ 'حالة_الاتصال_الخام' ],
	'anyuseronlinestatus' => [ 0, 'حالة_الاتصال_لأي_مستخدم' ],
];

/** Egyptian Arabic (مصرى) */
$magicWords['arz'] = [
	'onlinestatus_word' => [ 'حالة_الاتصال' ],
	'onlinestatus_word_raw' => [ 'حالة_الاتصال_الخام' ],
	'anyuseronlinestatus' => [ 0, 'حالة_الاتصال_لأى_مستخدم', 'حالة_الاتصال_لأي_مستخدم' ],
];

/** Breton (brezhoneg) */
$magicWords['br'] = [
	'onlinestatus_word' => [ 'STATUDENLINENN' ],
];

/** Chechen (нохчийн) */
$magicWords['ce'] = [
	'onlinestatus_word' => [ 'ЗӀЕЧОХЬСТАТУС', 'СТАТУСВСЕТИ' ],
	'onlinestatus_word_raw' => [ 'ЗӀЕНЧОХЬХЬАЛТӀУЬН', 'СТАТУСВСЕТИСЫР' ],
	'anyuseronlinestatus' => [ 0, 'мюлхдекъахохьалмашанчохь', 'любойучастникстатусвсети' ],
];

/** German (Deutsch) */
$magicWords['de'] = [
	'onlinestatus_word_raw' => [ 'ROHONLINESTATUS' ],
	'anyuseronlinestatus' => [ 0, 'onlinestatus_eines_benutzers' ],
];

/** Zazaki (Zazaki) */
$magicWords['diq'] = [
	'onlinestatus_word' => [ 'ONLINEWEZİYET' ],
	'onlinestatus_word_raw' => [ 'ONLINEWEZİYETNÉBİYO' ],
	'anyuseronlinestatus' => [ 0, 'karberékonlineweziyetnébiyé' ],
];

/** French (français) */
$magicWords['fr'] = [
	'onlinestatus_word' => [ 'ETATENLIGNE' ],
	'onlinestatus_word_raw' => [ 'ETATENLIGNEB' ],
	'anyuseronlinestatus' => [ 0, 'étatenligneutilisateur' ],
];

/** Japanese (日本語) */
$magicWords['ja'] = [
	'onlinestatus_word' => [ 'オンライン状況' ],
	'onlinestatus_word_raw' => [ '生オンライン状況' ],
	'anyuseronlinestatus' => [ 0, '匿名オンライン状況' ],
];

/** Korean (한국어) */
$magicWords['ko'] = [
	'onlinestatus_word' => [ '접속상태' ],
	'onlinestatus_word_raw' => [ '원래접속상태' ],
	'anyuseronlinestatus' => [ 0, '어떤사용자접속상태' ],
];

/** Macedonian (македонски) */
$magicWords['mk'] = [
	'onlinestatus_word' => [ 'ВКЛУЧЕНОСТ' ],
	'onlinestatus_word_raw' => [ 'СИРОВАВКЛУЧЕНОСТ' ],
	'anyuseronlinestatus' => [ 0, 'вклученостсекојкорисник' ],
];

/** Malayalam (മലയാളം) */
$magicWords['ml'] = [
	'onlinestatus_word' => [ 'ഓൺലൈൻസ്ഥിതി' ],
	'onlinestatus_word_raw' => [ 'ഓൺലൈൻസ്ഥിതി_അസംസ്കൃതം' ],
	'anyuseronlinestatus' => [ 0, 'ഏതൊരുപയോക്താവിന്റേയുമോൺലൈൻസ്ഥിതി' ],
];

/** Marathi (मराठी) */
$magicWords['mr'] = [
	'onlinestatus_word' => [ 'ऑनलाईनस्थिती' ],
	'onlinestatus_word_raw' => [ 'कच्चीऑनलाईनस्थिती' ],
	'anyuseronlinestatus' => [ 0, 'कोणीसदस्यऑनलाईनस्थिती' ],
];

/** Low Saxon (Netherlands) (Nedersaksies) */
$magicWords['nds-nl'] = [
	'onlinestatus_word' => [ 'ONLINESTAOTUS' ],
	'onlinestatus_word_raw' => [ 'ROEWEONLINESTAOTUS' ],
	'anyuseronlinestatus' => [ 0, 'allegebrukersonlinestaotus' ],
];

/** Dutch (Nederlands) */
$magicWords['nl'] = [
	'onlinestatus_word_raw' => [ 'RUWEONLINESTATUS' ],
	'anyuseronlinestatus' => [ 0, 'allegebruikersonlinestatus' ],
];

/** Oriya (ଓଡ଼ିଆ) */
$magicWords['or'] = [
	'onlinestatus_word' => [ 'ଅନଲାଇନଅବସ୍ଥା' ],
];

/** Polish (polski) */
$magicWords['pl'] = [
	'onlinestatus_word' => [ 'STATUSONLINE' ],
];

/** Russian (русский) */
$magicWords['ru'] = [
	'onlinestatus_word' => [ 'СТАТУСВСЕТИ', 'СТАТУС_В_СЕТИ' ],
	'onlinestatus_word_raw' => [ 'СТАТУСВСЕТИСЫР', 'СТАТУС_В_СЕТИ_СЫР' ],
	'anyuseronlinestatus' => [ 0, 'любойучастникстатусвсети', 'любой_участник_статус_в_сети' ],
];

/** Serbian (Latin script) (srpski (latinica)‎) */
$magicWords['sr-el'] = [
	'onlinestatus_word' => [ 'MREŽNO_STANJE' ],
	'onlinestatus_word_raw' => [ 'ČISTO_MREŽNO_STANJE' ],
	'anyuseronlinestatus' => [ 0, 'mrežno_stanje_svakog_korisnika' ],
];

/** Swedish (svenska) */
$magicWords['sv'] = [
	'onlinestatus_word_raw' => [ '1', 'RÅONLINESTATUS', 'RAWONLINESTATUS' ],
];

/** Turkish (Türkçe) */
$magicWords['tr'] = [
	'onlinestatus_word' => [ 'ÇEVRİMİÇİDURUMU' ],
	'onlinestatus_word_raw' => [ 'HAMÇEVRİMİÇİDURUMU' ],
	'anyuseronlinestatus' => [ 0, 'herhangibirkullanıcıçevrimiçidurumu' ],
];

/** Ukrainian (українська) */
$magicWords['uk'] = [
	'onlinestatus_word' => [ 'У_МЕРЕЖІ' ],
	'anyuseronlinestatus' => [ 0, 'будь-хто' ],
];

/** Simplified Chinese (中文（简体）‎) */
$magicWords['zh-hans'] = [
	'onlinestatus_word' => [ '在线状态' ],
	'onlinestatus_word_raw' => [ '原始在线状态' ],
	'anyuseronlinestatus' => [ 0, '任何用户在线状态' ],
];

/** Traditional Chinese (中文（繁體）‎) */
$magicWords['zh-hant'] = [
	'onlinestatus_word' => [ '線上狀態' ],
	'onlinestatus_word_raw' => [ '原先線上狀態' ],
	'anyuseronlinestatus' => [ 0, '任何使用者線上狀態' ],
];

==> OnlineStatus-REL1_39-2247b55.tar.gz: OnlineStatus/OnlineStatus.i18n.magic.php <==
<?php
/**
 * Internationalization file for magic words.
 */

$magicWords = [];

/** English (English) */
$magicWords['en'] = [
	'onlinestatus_word' => [ '1', 'ONLINESTATUS' ],
	'onlinestatus_word_raw' => [ '1', 'RAWONLINESTATUS' ],
	'anyuseronlinestatus' => [ 0, 'anyuseronlinestatus' ],
];

/** Arabic (العربية) */
$magicWords['ar'] = [
	'onlinestatus_word' => [ 'حالة_الاتصال' ],
	'onlinestatus_word_raw' => [ 'حالة_الاتصال_الخام' ],
	'anyuseronlinestatus' => [ 0, 'حالة_الاتصال_لأي_مستخدم' ],
];

/** Egyptian Arabic (مصرى) */
$magicWords['arz'] = [
	'onlinestatus_word' => [ 'حالة_الاتصال' ],
	'onlinestatus_word_raw' => [ 'حالة_الاتصال_الخام' ],
	'anyuseronlinestatus' => [ 0, 'حالة_الاتصال_لأى_مستخدم', 'حالة_الاتصال_لأي_مستخدم' ],
];

/** Breton (brezhoneg) */
$magicWords['br'] = [
	'onlinestatus_word' => [ 'STATUDENLINENN' ],
];

/** Chechen (нохчийн) */
$magicWords['ce'] = [
	'onlinestatus_word' => [ 'ЗӀЕЧОХЬСТАТУС', 'СТАТУСВСЕТИ' ],
	'onlinestatus_word_raw' => [ 'ЗӀЕНЧОХЬХЬАЛТӀУЬН', 'СТАТУСВСЕТИСЫР' ],
	'anyuseronlinestatus' => [ 0, 'мюлхдекъахохьалмашанчохь', 'любойучастникстатусвсети' ],
];

/** German (Deutsch) */
$magicWords['de'] = [
	'onlinestatus_word_raw' => [ 'ROHONLINESTATUS' ],
	'anyuseronlinestatus' => [ 0, 'onlinestatus_eines_benutzers' ],
];

/** Zazaki (Zazaki) */
$magicWords['diq'] = [
	'onlinestatus_word' => [ 'ONLINEWEZİYET' ],
	'onlinestatus_word_raw' => [ 'ONLINEWEZİYETNÉBİYO' ],
	'anyuseronlinestatus' => [ 0, 'karberékonlineweziyetnébiyé' ],
];

/** French (français) */
$magicWords['fr'] = [
	'onlinestatus_word' => [ 'ETATENLIGNE' ],
	'onlinestatus_word_raw' => [ 'ETATENLIGNEB' ],
	'anyuseronlinestatus' => [ 0, 'étatenligneutilisateur' ],
];

/** Japanese (日本語) */
$magicWords['ja'] = [
	'onlinestatus_word' => [ 'オンライン状況' ],
	'onlinestatus_word_raw' => [ '生オンライン状況' ],
	'anyuseronlinestatus' => [ 0, '匿名オンライン状況' ],
];

/** Korean (한국어) */
$magicWords['ko'] = [
	'onlinestatus_word' => [ '접속상태' ],
	'onlinestatus_word_raw' => [ '원래접속상태' ],
	'anyuseronlinestatus' => [ 0, '어떤사용자접속상태' ],
];

/** Macedonian (македонски) */
$magicWords['mk'] = [
	'onlinestatus_word' => [ 'ВКЛУЧЕНОСТ' ],
	'onlinestatus_word_raw' => [ 'СИРОВАВКЛУЧЕНОСТ' ],
	'anyuseronlinestatus' => [ 0, 'вклученостсекојкорисник' ],
];

/** Malayalam (മലയാളം) */
$magicWords['ml'] = [
	'onlinestatus_word' => [ 'ഓൺലൈൻസ്ഥിതി' ],
	'onlinestatus_word_raw' => [ 'ഓൺലൈൻസ്ഥിതി_അസംസ്കൃതം' ],
	'anyuseronlinestatus' => [ 0, 'ഏതൊരുപയോക്താവിന്റേയുമോൺലൈൻസ്ഥിതി' ],
];

/** Marathi (मराठी) */
$magicWords['mr'] = [
	'onlinestatus_word' => [ 'ऑनलाईनस्थिती' ],
	'onlinestatus_word_raw' => [ 'कच्चीऑनलाईनस्थिती' ],
	'anyuseronlinestatus' => [ 0, 'कोणीसदस्यऑनलाईनस्थिती' ],
];

/** Low Saxon (Netherlands) (Nedersaksies) */
$magicWords['nds-nl'] = [
	'onlinestatus_word' => [ 'ONLINESTAOTUS' ],
	'onlinestatus_word_raw' => [ 'ROEWEONLINESTAOTUS' ],
	'anyuseronlinestatus' => [ 0, 'allegebrukersonlinestaotus' ],
];

/** Dutch (Nederlands) */
$magicWords['nl'] = [
	'onlinestatus_word_raw' => [ 'RUWEONLINESTATUS' ],
	'anyuseronlinestatus' => [ 0, 'allegebruikersonlinestatus' ],
];

/** Oriya (ଓଡ଼ିଆ) */
$magicWords['or'] = [
	'onlinestatus_word' => [ 'ଅନଲାଇନଅବସ୍ଥା' ],
];

/** Polish (polski) */
$magicWords['pl'] = [
	'onlinestatus_word' => [ 'STATUSONLINE' ],
];

/** Russian (русский) */
$magicWords['ru'] = [
	'onlinestatus_word' => [ 'СТАТУСВСЕТИ', 'СТАТУС_В_СЕТИ' ],
	'onlinestatus_word_raw' => [ 'СТАТУСВСЕТИСЫР', 'СТАТУС_В_СЕТИ_СЫР' ],
	'anyuseronlinestatus' => [ 0, 'любойучастникстатусвсети', 'любой_участник_статус_в_сети' ],
];

/** Serbian (Latin script) (srpski (latinica)) */
$magicWords['sr-el'] = [
	'onlinestatus_word' => [ 'MREŽNO_STANJE' ],
	'onlinestatus_word_raw' => [ 'ČISTO_MREŽNO_STANJE' ],
	'anyuseronlinestatus' => [ 0, 'mrežno_stanje_svakog_korisnika' ],
];

/** Swedish (svenska) */
$magicWords['sv'] = [
	'onlinestatus_word_raw' => [ '1', 'RÅONLINESTATUS', 'RAWONLINESTATUS' ],
];

/** Turkish (Türkçe) */
$magicWords['tr'] = [
	'onlinestatus_word' => [ 'ÇEVRİMİÇİDURUMU' ],
	'onlinestatus_word_raw' => [ 'HAMÇEVRİMİÇİDURUMU' ],
	'anyuseronlinestatus' => [ 0, 'herhangibirkullanıcıçevrimiçidurumu' ],
];

/** Ukrainian (українська) */
$magicWords['uk'] = [
	'onlinestatus_word' => [ 'У_МЕРЕЖІ' ],
	'anyuseronlinestatus' => [ 0, 'будь-хто' ],
];

/** Simplified Chinese (中文（简体）) */
$magicWords['zh-hans'] = [
	'onlinestatus_word' => [ '在线状态' ],
	'onlinestatus_word_raw' => [ '原始在线状态' ],
	'anyuseronlinestatus' => [ 0, '任何用户在线状态' ],
];

/** Traditional Chinese (中文（繁體）) */
$magicWords['zh-hant'] = [
	'onlinestatus_word' => [ '線上狀態' ],
	'onlinestatus_word_raw' => [ '原先線上狀態' ],
	'anyuseronlinestatus' => [ 0, '任何使用者線上狀態' ],
];
